@@ -60,7 +60,7 @@
 #include <libgimp/gimp.h>
 
 #define PLUG_IN_NAME    "plug_in_quant"
-#define PLUG_IN_VERSION "Feb 1998, 0.95"
+#define PLUG_IN_VERSION "Mar 1998, 0.96"
 
 #define ENTRY_WIDTH 100
 
@@ -769,10 +769,11 @@ static void invert (A,B)
 static void build_histogram (GDrawable *drawable)
 {
   hash_table_entry  **hash_table, *entry, *next; 
-  guchar *sp;
+  guchar *sp, *src;
   int hash;
   GPixelRgn src_rgn;
-  gint x, y, progress, max_progress;
+  guint x, y;
+  gint progress, max_progress;
   gint x1, x2, y1, y2;
   gpointer pr;
   color *c;
@@ -790,8 +791,9 @@ static void build_histogram (GDrawable *drawable)
   gimp_progress_init ("(1/3) Building histogram...");
 
   for (pr = gimp_pixel_rgns_register (1, &src_rgn); pr != NULL; pr = gimp_pixel_rgns_process (pr)) {
-    sp=src_rgn.data;
+    src=src_rgn.data;
     for (y = 0; y < src_rgn.h; y++) {
+      sp=src;
       for (x = 0; x < src_rgn.w; x++, sp += src_rgn.bpp) {
         hash = HASH_FUNC(sp);      
         for (entry = hash_table[hash]; ; entry = entry->next) {
@@ -813,6 +815,7 @@ static void build_histogram (GDrawable *drawable)
 	  }
         }
       }
+      src += src_rgn.rowstride;
     }
     progress += src_rgn.w * src_rgn.h;
     gimp_progress_update ((double) progress / (double) max_progress);
@@ -843,17 +846,18 @@ static void build_histogram (GDrawable *drawable)
 static void map_hashed (GDrawable *drawable, sample *lut, int len)
 {
   hash_table_entry **hash_table, *entry, *hash_store, *next_free;
-  guchar *sp;
-  guchar *dp;
+  guchar *sp, *src;
+  guchar *dp, *dest;
   int hash;
   float dist, newdist, cs[3];
   sample *s, *last_s, t, v;
   float sdist [len][len], mdist[len];
-  int rest, i, j, idx;
+  int i, j, idx;
   GPixelRgn src_rgn, dest_rgn;
   gpointer pr;
   gint x1,x2,y1,y2;
-  gint x,y,progress,max_progress;
+  guint x,y, rest;
+  gint progress,max_progress;
 
   gimp_drawable_mask_bounds (drawable->id, &x1, &y1, &x2, &y2);
 
@@ -917,9 +921,11 @@ static void map_hashed (GDrawable *drawable, sample *lut, int len)
   gimp_progress_init("(3/3) Applying color map...");
 
   for (pr = gimp_pixel_rgns_register (2, &src_rgn, &dest_rgn); pr != NULL; pr = gimp_pixel_rgns_process (pr)) {
-    sp = src_rgn.data;
-    dp = dest_rgn.data;
+    src = src_rgn.data;
+    dest = dest_rgn.data;
     for (y = 0; y < src_rgn.h; y++) {
+      sp = src;
+      dp = dest;
       for (x = 0; x < src_rgn.w; x++) {
         hash = HASH_FUNC(sp);
         idx = -1;
@@ -963,6 +969,8 @@ static void map_hashed (GDrawable *drawable, sample *lut, int len)
         sp += src_rgn.bpp;
         dp += dest_rgn.bpp;
       }
+      src += src_rgn.rowstride;
+      dest += dest_rgn.rowstride;
     }
     progress += src_rgn.w*src_rgn.h;
     gimp_progress_update((double) progress/ (double) max_progress);
